======
Django Bridger
======

A django app, that bridges the gap between the backend and frontend to enable automatic creation of frontend apps.

This is a Pre-Release Version and should not be used in production!